@@ -1,4 +1,4 @@
-// Copyright (C) 2013-2018 Internet Systems Consortium, Inc. ("ISC")
+// Copyright (C) 2013-2020 Internet Systems Consortium, Inc. ("ISC")
 //
 // This Source Code Form is subject to the terms of the Mozilla Public
 // License, v. 2.0. If a copy of the MPL was not distributed with this
@@ -427,8 +427,9 @@ TSIGKeyInfoParser::parse(ConstElementPtr key_config) {
           && (digestbits < 192)) ||
          (boost::iequals(algorithm, TSIGKeyInfo::HMAC_SHA512_STR)
           && (digestbits < 256)))) {
-        isc_throw(D2CfgError, "tsig-key: digest-bits too small : "
-                  << " (" << getPosition("digest-bits", key_config) << ")");
+        isc_throw(D2CfgError, "tsig-key: digest-bits too small : ("
+                                  << getPosition("digest-bits", key_config)
+                                  << ")");
         }
 
     // Everything should be valid, so create the key instance.
