@@ -1,8 +1,8 @@
-// A Bison parser, made by GNU Bison 3.7.4.
+// A Bison parser, made by GNU Bison 3.7.5.
 
 // Skeleton implementation for Bison LALR(1) parsers in C++
 
-// Copyright (C) 2002-2015, 2018-2020 Free Software Foundation, Inc.
+// Copyright (C) 2002-2015, 2018-2021 Free Software Foundation, Inc.
 
 // This program is free software: you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -125,7 +125,7 @@
 #else // !NETCONF_DEBUG
 
 # define YYCDEBUG if (false) std::cerr
-# define YY_SYMBOL_PRINT(Title, Symbol)  YYUSE (Symbol)
+# define YY_SYMBOL_PRINT(Title, Symbol)  YY_USE (Symbol)
 # define YY_REDUCE_PRINT(Rule)           static_cast<void> (0)
 # define YY_STACK_PRINT()                static_cast<void> (0)
 
@@ -366,7 +366,7 @@ namespace isc { namespace netconf {
   NetconfParser::yy_print_ (std::ostream& yyo, const basic_symbol<Base>& yysym) const
   {
     std::ostream& yyoutput = yyo;
-    YYUSE (yyoutput);
+    YY_USE (yyoutput);
     if (yysym.empty ())
       yyo << "empty symbol";
     else
@@ -1948,7 +1948,7 @@ namespace isc { namespace netconf {
   const short
   NetconfParser::yydefgoto_[] =
   {
-      -1,     4,     5,     6,     7,    23,    27,    16,    17,    18,
+       0,     4,     5,     6,     7,    23,    27,    16,    17,    18,
       25,    91,    32,    33,    19,    24,    29,    30,   173,    21,
       26,    35,    62,    46,    47,    48,   174,   175,   176,   177,
       64,   178,    65,    54,    70,   111,   112,   113,   124,   138,
