@@ -1,4 +1,4 @@
-// Copyright (C) 2012-2020 Internet Systems Consortium, Inc. ("ISC")
+// Copyright (C) 2012-2021 Internet Systems Consortium, Inc. ("ISC")
 //
 // This Source Code Form is subject to the terms of the Mozilla Public
 // License, v. 2.0. If a copy of the MPL was not distributed with this
@@ -237,12 +237,16 @@ BasicScen::run() {
         tc_.printTemplates();
     }
 
+    // Print any received leases.
+    if (options_.testDiags('l')) {
+        stats_mgr.printLeases();
+    }
+
     int ret_code = 0;
     // Check if any packet drops occurred.
     ret_code = stats_mgr.droppedPackets() ? 3 : 0;
     return (ret_code);
 }
 
-
-}
-}
+}  // namespace perfdhcp
+}  // namespace isc
