@@ -1,4 +1,4 @@
-// Copyright (C) 2012-2020 Internet Systems Consortium, Inc. ("ISC")
+// Copyright (C) 2012-2021 Internet Systems Consortium, Inc. ("ISC")
 //
 // This Source Code Form is subject to the terms of the Mozilla Public
 // License, v. 2.0. If a copy of the MPL was not distributed with this
@@ -39,6 +39,13 @@ enum class ExchangeType {
     RL   ///< DHCPv6 RELEASE-REPLY
 };
 
+/// \brief Get the DHCP version that fits the exchange type.
+///
+/// \param exchange_type exchange type that will determine the version
+/// \throw isc::BadValue exchange type is unrecognized
+/// \return DHCP version: 4 or 6
+int dhcpVersion(ExchangeType const exchange_type);
+
 /// \brief Return name of the exchange.
 ///
 /// Function returns name of the specified exchange type.
@@ -555,6 +562,19 @@ public:
         return(std::make_tuple(sent_packets_.begin(), sent_packets_.end()));
     }
 
+    /// \brief Return the list of received leases in CSV format as string.
+    ///
+    /// Depending exchange type, it can apply to
+    /// potential leases received in offers and advertisements,
+    /// committed leases received in acknowledgements and replies,
+    /// renewed or released leases.
+    ///
+    /// \return multiline string of received leases in CSV format
+    std::string receivedLeases() const;
+
+    /// \brief Print the list of received leases.
+    void printLeases() const;
+
     static int malformed_pkts_;
 
 // Private stuff of ExchangeStats class
@@ -1159,6 +1179,9 @@ public:
         }
     }
 
+    /// \brief Delegate to all exchanges to print their leases.
+    void printLeases() const;
+
     /// \brief Print names and values of custom counters.
     ///
     /// Method prints names and values of custom counters. Custom counters
