@@ -1,4 +1,4 @@
-// File created from ../../../../src/hooks/dhcp/high_availability/ha_messages.mes on Mon Dec 14 2020 03:36
+// File created from ../../../../src/hooks/dhcp/high_availability/ha_messages.mes
 
 #ifndef HA_MESSAGES_H
 #define HA_MESSAGES_H
@@ -44,10 +44,18 @@ extern const isc::log::MessageID HA_HEARTBEAT_HANDLER_FAILED;
 extern const isc::log::MessageID HA_HIGH_CLOCK_SKEW;
 extern const isc::log::MessageID HA_HIGH_CLOCK_SKEW_CAUSES_TERMINATION;
 extern const isc::log::MessageID HA_INIT_OK;
+extern const isc::log::MessageID HA_INVALID_PARTNER_STATE_COMMUNICATION_RECOVERY;
+extern const isc::log::MessageID HA_INVALID_PARTNER_STATE_HOT_STANDBY;
+extern const isc::log::MessageID HA_INVALID_PARTNER_STATE_LOAD_BALANCING;
 extern const isc::log::MessageID HA_LEASES4_COMMITTED_FAILED;
 extern const isc::log::MessageID HA_LEASES4_COMMITTED_NOTHING_TO_UPDATE;
 extern const isc::log::MessageID HA_LEASES6_COMMITTED_FAILED;
 extern const isc::log::MessageID HA_LEASES6_COMMITTED_NOTHING_TO_UPDATE;
+extern const isc::log::MessageID HA_LEASES_BACKLOG_COMMUNICATIONS_FAILED;
+extern const isc::log::MessageID HA_LEASES_BACKLOG_FAILED;
+extern const isc::log::MessageID HA_LEASES_BACKLOG_NOTHING_TO_SEND;
+extern const isc::log::MessageID HA_LEASES_BACKLOG_START;
+extern const isc::log::MessageID HA_LEASES_BACKLOG_SUCCESS;
 extern const isc::log::MessageID HA_LEASES_SYNC_COMMUNICATIONS_FAILED;
 extern const isc::log::MessageID HA_LEASES_SYNC_FAILED;
 extern const isc::log::MessageID HA_LEASES_SYNC_LEASE_PAGE_RECEIVED;
@@ -75,6 +83,9 @@ extern const isc::log::MessageID HA_MAINTENANCE_STARTED;
 extern const isc::log::MessageID HA_MAINTENANCE_STARTED_IN_PARTNER_DOWN;
 extern const isc::log::MessageID HA_MAINTENANCE_START_HANDLER_FAILED;
 extern const isc::log::MessageID HA_MISSING_CONFIGURATION;
+extern const isc::log::MessageID HA_RESET_COMMUNICATIONS_FAILED;
+extern const isc::log::MessageID HA_RESET_FAILED;
+extern const isc::log::MessageID HA_RESET_HANDLER_FAILED;
 extern const isc::log::MessageID HA_SCOPES_HANDLER_FAILED;
 extern const isc::log::MessageID HA_SERVICE_STARTED;
 extern const isc::log::MessageID HA_STATE_MACHINE_CONTINUED;
