@@ -1,4 +1,4 @@
-// Copyright (C) 2017-2020 Internet Systems Consortium, Inc. ("ISC")
+// Copyright (C) 2017-2021 Internet Systems Consortium, Inc. ("ISC")
 //
 // This Source Code Form is subject to the terms of the Mozilla Public
 // License, v. 2.0. If a copy of the MPL was not distributed with this
@@ -45,15 +45,6 @@ public:
         : StateType(io_service, config) {
     }
 
-    /// @brief Modifies poke time by adding seconds to it.
-    ///
-    /// @param secs number of seconds to be added to the poke time. If
-    /// the value is negative it will set the poke time in the past
-    /// comparing to current value.
-    void modifyPokeTime(const long secs) {
-        StateType::poke_time_ += boost::posix_time::seconds(secs);
-    }
-
     /// @brief Checks if the object was poked recently.
     ///
     /// @return true if the object was poked less than 5 seconds ago,
@@ -151,7 +142,7 @@ public:
                                  HAConfig::LOAD_BALANCING) const;
 
     /// @brief Return HA configuration with one primary and two backup
-    /// serveers in the JSON format.
+    /// servers in the JSON format.
     ///
     /// @return Pointer to the unparsed configuration.
     data::ConstElementPtr
@@ -159,8 +150,10 @@ public:
 
     /// @brief Return HA configuration with three servers.
     ///
+    /// @param ha_mode HA operation mode (default is load balancing).
     /// @return Pointer to the parsed configuration.
-    HAConfigPtr createValidConfiguration() const;
+    HAConfigPtr createValidConfiguration(const HAConfig::HAMode& ha_mode =
+                                         HAConfig::LOAD_BALANCING) const;
 
     /// @brief Return passive-backup configuration.
     ///
