@@ -398,8 +398,8 @@ CfgSubnets4::selectSubnet(const std::string& iface,
         Subnet4Ptr subnet_selected;
 
         // First, try subnet specific interface name.
-        if (!(*subnet)->getIface().empty()) {
-            if ((*subnet)->getIface() == iface) {
+        if (!(*subnet)->getIface(Network4::Inheritance::NONE).empty()) {
+            if ((*subnet)->getIface(Network4::Inheritance::NONE) == iface) {
                 subnet_selected = (*subnet);
             }
 
@@ -409,8 +409,8 @@ CfgSubnets4::selectSubnet(const std::string& iface,
             // the interface.
             SharedNetwork4Ptr network;
             (*subnet)->getSharedNetwork(network);
-            if (network && !network->getIface().empty() &&
-                (network->getIface() == iface)) {
+            if (network &&
+                (network->getIface(Network4::Inheritance::NONE) == iface)) {
                 subnet_selected = (*subnet);
             }
         }
@@ -491,7 +491,7 @@ CfgSubnets4::removeStatistics() {
                                              "declined-addresses"));
 
         stats_mgr.del(StatsMgr::generateName("subnet", subnet_id,
-                                             "declined-reclaimed-addresses"));
+                                             "reclaimed-declined-addresses"));
 
         stats_mgr.del(StatsMgr::generateName("subnet", subnet_id,
                                              "reclaimed-leases"));
@@ -521,7 +521,7 @@ CfgSubnets4::updateStatistics() {
 
     // Only recount the stats if we have subnets.
     if (subnets_.begin() != subnets_.end()) {
-            LeaseMgrFactory::instance().recountLeaseStats4();
+        LeaseMgrFactory::instance().recountLeaseStats4();
     }
 }
 
