@@ -1,4 +1,4 @@
-// Copyright (C) 2013-2019 Internet Systems Consortium, Inc. ("ISC")
+// Copyright (C) 2013-2021 Internet Systems Consortium, Inc. ("ISC")
 //
 // This Source Code Form is subject to the terms of the Mozilla Public
 // License, v. 2.0. If a copy of the MPL was not distributed with this
@@ -221,8 +221,6 @@ public:
     void parse(SrvConfig& srv_cfg, isc::data::ConstElementPtr value);
 };
 
-typedef std::pair<isc::dhcp::OptionDefinitionPtr, std::string> OptionDefinitionTuple;
-
 /// @brief Parser for a single option definition.
 ///
 /// This parser creates an instance of a single option definition.
@@ -236,11 +234,10 @@ public:
     /// @brief Parses an entry that describes single option definition.
     ///
     /// @param option_def a configuration entry to be parsed.
-    /// @return tuple (option definition, option space) of the parsed structure
+    /// @return option definition of the parsed structure.
     ///
     /// @throw DhcpConfigError if parsing was unsuccessful.
-    OptionDefinitionTuple
-    parse(isc::data::ConstElementPtr option_def);
+    OptionDefinitionPtr parse(isc::data::ConstElementPtr option_def);
 
 private:
     /// @brief Address family: @c AF_INET or @c AF_INET6.
@@ -474,7 +471,9 @@ public:
     /// @brief constructor
     ///
     /// @param family address family: @c AF_INET or @c AF_INET6
-    explicit SubnetConfigParser(uint16_t family);
+    /// @param check_iface Check if the specified interface exists in
+    /// the system.
+    explicit SubnetConfigParser(uint16_t family, bool check_iface = true);
 
     /// @brief virtual destructor (does nothing)
     virtual ~SubnetConfigParser() { }
@@ -525,6 +524,9 @@ protected:
 
     /// Pointer to the options configuration.
     CfgOptionPtr options_;
+
+    /// Check if the specified interface exists in the system.
+    bool check_iface_;
 };
 
 /// @anchor Subnet4ConfigParser
@@ -538,7 +540,10 @@ public:
     /// @brief Constructor
     ///
     /// stores global scope parameters, options, option definitions.
-    Subnet4ConfigParser();
+    ///
+    /// @param check_iface Check if the specified interface exists in
+    /// the system.
+    Subnet4ConfigParser(bool check_iface = true);
 
     /// @brief Parses a single IPv4 subnet configuration and adds to the
     /// Configuration Manager.
@@ -557,6 +562,13 @@ protected:
     /// @param len is the prefix length
     void initSubnet(data::ConstElementPtr params,
                     asiolink::IOAddress addr, uint8_t len);
+
+    /// @brief Verifies the host reservation address is in the subnet range
+    ///
+    /// @param subnet pointer to the subnet
+    /// @param host pointer to the host reservation
+    /// @throw DhcpConfigError when the address is not in the subnet range.
+    void validateResv(const Subnet4Ptr& subnet, ConstHostPtr host);
 };
 
 /// @brief this class parses list of DHCP4 subnets
@@ -567,6 +579,12 @@ protected:
 class Subnets4ListConfigParser : public isc::data::SimpleParser {
 public:
 
+    /// @brief constructor
+    ///
+    /// @param check_iface Check if the specified interface exists in
+    /// the system.
+    Subnets4ListConfigParser(bool check_iface = true);
+
     /// @brief parses contents of the list
     ///
     /// Iterates over all entries on the list, parses its content
@@ -585,6 +603,11 @@ public:
     /// @return Number of subnets created.
     size_t parse(Subnet4Collection& subnets,
                  data::ConstElementPtr subnets_list);
+
+protected:
+
+    /// Check if the specified interface exists in the system.
+    bool check_iface_;
 };
 
 /// @brief Parser for IPv6 pool definitions.
@@ -721,7 +744,10 @@ public:
     /// @brief Constructor
     ///
     /// stores global scope parameters, options, option definitions.
-    Subnet6ConfigParser();
+    ///
+    /// @param check_iface Check if the specified interface exists in
+    /// the system.
+    Subnet6ConfigParser(bool check_iface = true);
 
     /// @brief Parses a single IPv6 subnet configuration and adds to the
     /// Configuration Manager.
@@ -749,6 +775,13 @@ protected:
     /// @param len is the prefix length
     void initSubnet(isc::data::ConstElementPtr params,
                     isc::asiolink::IOAddress addr, uint8_t len);
+
+    /// @brief Verifies host reservation addresses are in the subnet range
+    ///
+    /// @param subnet pointer to the subnet
+    /// @param host pointer to the host reservation
+    /// @throw DhcpConfigError when an address is not in the subnet range.
+    void validateResvs(const Subnet6Ptr& subnet, ConstHostPtr host);
 };
 
 
@@ -760,6 +793,12 @@ protected:
 class Subnets6ListConfigParser : public isc::data::SimpleParser {
 public:
 
+    /// @brief constructor
+    ///
+    /// @param check_iface Check if the specified interface exists in
+    /// the system.
+    Subnets6ListConfigParser(bool check_iface = true);
+
     /// @brief parses contents of the list
     ///
     /// Iterates over all entries on the list, parses its content
@@ -779,6 +818,10 @@ public:
     size_t parse(Subnet6Collection& subnets,
                  data::ConstElementPtr subnets_list);
 
+protected:
+
+    /// Check if the specified interface exists in the system.
+    bool check_iface_;
 };
 
 /// @brief Parser for  D2ClientConfig
@@ -853,7 +896,7 @@ private:
     getMode(isc::data::ConstElementPtr scope, const std::string& name);
 };
 
-}; // end of isc::dhcp namespace
-}; // end of isc namespace
+} // end of isc::dhcp namespace
+} // end of isc namespace
 
 #endif // DHCP_PARSERS_H
