@@ -10,6 +10,7 @@
 #include <asiolink/io_service.h>
 #include <dhcpsrv/timer_mgr.h>
 #include <exceptions/exceptions.h>
+#include <testutils/multi_threading_utils.h>
 
 #include <gtest/gtest.h>
 
@@ -20,6 +21,7 @@
 using namespace isc;
 using namespace isc::dhcp;
 using namespace isc::asiolink;
+using namespace isc::test;
 
 namespace {
 
@@ -84,6 +86,29 @@ public:
     /// @c timeout_ member.
     void timeoutCallback();
 
+    // @brief This test checks that certain errors are returned when invalid
+    // parameters are specified when registering a timer, or when
+    // the registration can't be made.
+    void testRegisterTimer();
+
+    /// @brief This test verifies that it is possible to unregister a timer from
+    /// the TimerMgr.
+    void testUnregisterTimer();
+
+    /// @brief This test verifies that it is possible to unregister all timers.
+    void testUnregisterTimers();
+
+    /// @brief This test verifies that the timer execution can be cancelled.
+    void testCancel();
+
+    /// @brief This test verifies that the callbacks for the scheduled timers
+    /// are actually called.
+    void testScheduleTimers();
+
+    /// @brief  This test verifies that exceptions emitted from the callback
+    /// would be handled by the TimerMgr.
+    void testCallbackWithException();
+
     /// @brief Type definition for a map holding calls counters for
     /// timers.
     typedef std::map<std::string, unsigned int> CallsCount;
@@ -167,7 +192,8 @@ TimerMgrTest::makeCallbackWithException() {
 // This test checks that certain errors are returned when invalid
 // parameters are specified when registering a timer, or when
 // the registration can't be made.
-TEST_F(TimerMgrTest, registerTimer) {
+void
+TimerMgrTest::testRegisterTimer() {
     // Empty timer name is not allowed.
     ASSERT_THROW(timer_mgr_->registerTimer("", makeCallback("timer1"), 1,
                                            IntervalTimer::ONE_SHOT),
@@ -185,9 +211,20 @@ TEST_F(TimerMgrTest, registerTimer) {
                  BadValue);
 }
 
-// This test verifies that it is possible to unregister a timer from
-// the TimerMgr.
-TEST_F(TimerMgrTest, unregisterTimer) {
+TEST_F(TimerMgrTest, registerTimer) {
+    // Disable Multi-Threading.
+    MultiThreadingTest mt(false);
+    testRegisterTimer();
+}
+
+TEST_F(TimerMgrTest, registerTimerMultiThreading) {
+    // Enable Multi-Threading.
+    MultiThreadingTest mt(true);
+    testRegisterTimer();
+}
+
+void
+TimerMgrTest::testUnregisterTimer() {
     // Register a timer and start it.
     ASSERT_NO_FATAL_FAILURE(registerTimer("timer1", 1));
     ASSERT_EQ(1, timer_mgr_->timersCount());
@@ -218,8 +255,20 @@ TEST_F(TimerMgrTest, unregisterTimer) {
     EXPECT_EQ(calls_count_["timer1"], calls_count);
 }
 
-// This test verifies taht it is possible to unregister all timers.
-TEST_F(TimerMgrTest, unregisterTimers) {
+TEST_F(TimerMgrTest, unregisterTimer) {
+    // Disable Multi-Threading.
+    MultiThreadingTest mt(false);
+    testUnregisterTimer();
+}
+
+TEST_F(TimerMgrTest, unregisterTimerMultiThreading) {
+    // Enable Multi-Threading.
+    MultiThreadingTest mt(true);
+    testUnregisterTimer();
+}
+
+void
+TimerMgrTest::testUnregisterTimers() {
     // Register 10 timers.
     for (int i = 1; i <= 20; ++i) {
         std::ostringstream s;
@@ -262,8 +311,20 @@ TEST_F(TimerMgrTest, unregisterTimers) {
     EXPECT_TRUE(calls_count == calls_count_);
 }
 
-// This test verifies that the timer execution can be cancelled.
-TEST_F(TimerMgrTest, cancel) {
+TEST_F(TimerMgrTest, unregisterTimers) {
+    // Disable Multi-Threading.
+    MultiThreadingTest mt(false);
+    testUnregisterTimers();
+}
+
+TEST_F(TimerMgrTest, unregisterTimersMultiThreading) {
+    // Enable Multi-Threading.
+    MultiThreadingTest mt(true);
+    testUnregisterTimers();
+}
+
+void
+TimerMgrTest::testCancel() {
     // Register timer.
     ASSERT_NO_FATAL_FAILURE(registerTimer("timer1", 1));
 
@@ -299,9 +360,20 @@ TEST_F(TimerMgrTest, cancel) {
     EXPECT_GT(calls_count_["timer1"], calls_count);
 }
 
-// This test verifies that the callbacks for the scheduled timers are
-// actually called.
-TEST_F(TimerMgrTest, scheduleTimers) {
+TEST_F(TimerMgrTest, cancel) {
+    // Disable Multi-Threading.
+    MultiThreadingTest mt(false);
+    testCancel();
+}
+
+TEST_F(TimerMgrTest, cancelMultiThreading) {
+    // Enable Multi-Threading.
+    MultiThreadingTest mt(true);
+    testCancel();
+}
+
+void
+TimerMgrTest::testScheduleTimers() {
     // Register two timers: 'timer1' and 'timer2'. The first timer will
     // be executed at the 50ms interval. The second one at the 100ms
     // interval.
@@ -353,9 +425,20 @@ TEST_F(TimerMgrTest, scheduleTimers) {
     EXPECT_GT(calls_count_["timer2"], calls_count_timer2);
 }
 
-// This test verifies that exceptions emitted from the callback would
-// be handled by the TimerMgr.
-TEST_F(TimerMgrTest, callbackWithException) {
+TEST_F(TimerMgrTest, scheduleTimers) {
+    // Disable Multi-Threading.
+    MultiThreadingTest mt(false);
+    testScheduleTimers();
+}
+
+TEST_F(TimerMgrTest, scheduleTimersMultiThreading) {
+    // Enable Multi-Threading.
+    MultiThreadingTest mt(true);
+    testScheduleTimers();
+}
+
+void
+TimerMgrTest::testCallbackWithException() {
     // Create timer which will trigger callback generating exception.
     ASSERT_NO_THROW(
         timer_mgr_->registerTimer("timer1", makeCallbackWithException(), 1,
@@ -370,6 +453,18 @@ TEST_F(TimerMgrTest, callbackWithException) {
     doWait(500);
 }
 
+TEST_F(TimerMgrTest, callbackWithException) {
+    // Disable Multi-Threading.
+    MultiThreadingTest mt(false);
+    testCallbackWithException();
+}
+
+TEST_F(TimerMgrTest, callbackWithExceptionMultiThreading) {
+    // Enable Multi-Threading.
+    MultiThreadingTest mt(true);
+    testCallbackWithException();
+}
+
 // This test verifies that IO service specified for the TimerMgr
 // must not be null.
 TEST_F(TimerMgrTest, setIOService) {
