@@ -1,4 +1,4 @@
-// Copyright (C) 2012-2020 Internet Systems Consortium, Inc. ("ISC")
+// Copyright (C) 2012-2021 Internet Systems Consortium, Inc. ("ISC")
 //
 // This Source Code Form is subject to the terms of the Mozilla Public
 // License, v. 2.0. If a copy of the MPL was not distributed with this
@@ -7,6 +7,7 @@
 #ifndef MYSQL_CONNECTION_H
 #define MYSQL_CONNECTION_H
 
+#include <asiolink/io_service.h>
 #include <database/database_connection.h>
 #include <database/db_exceptions.h>
 #include <database/db_log.h>
@@ -70,7 +71,6 @@ private:
 ///
 /// Each statement is associated with an index, which is used to reference the
 /// associated prepared statement.
-
 struct TaggedStatement {
     uint32_t index;
     const char* text;
@@ -239,8 +239,15 @@ public:
     /// @brief Constructor
     ///
     /// Initialize MySqlConnection object with parameters needed for connection.
-    MySqlConnection(const ParameterMap& parameters)
-        : DatabaseConnection(parameters) {
+    ///
+    /// @param parameters Specify the connection details.
+    /// @param io_service The IOService object, used for all ASIO operations.
+    /// @param callback The connection recovery callback.
+    MySqlConnection(const ParameterMap& parameters,
+                    const isc::asiolink::IOServicePtr& io_service = isc::asiolink::IOServicePtr(),
+                    DbCallback callback = DbCallback())
+        : DatabaseConnection(parameters), io_service_(io_service),
+          callback_(callback) {
     }
 
     /// @brief Destructor
@@ -399,6 +406,7 @@ public:
                      const MySqlBindingCollection& in_bindings,
                      MySqlBindingCollection& out_bindings,
                      ConsumeResultFun process_result) {
+        checkUnusable();
         // Extract native input bindings.
         std::vector<MYSQL_BIND> in_bind_vec;
         for (MySqlBindingPtr in_binding : in_bindings) {
@@ -476,6 +484,7 @@ public:
     template<typename StatementIndex>
     void insertQuery(const StatementIndex& index,
                      const MySqlBindingCollection& in_bindings) {
+        checkUnusable();
         std::vector<MYSQL_BIND> in_bind_vec;
         for (MySqlBindingPtr in_binding : in_bindings) {
             in_bind_vec.push_back(in_binding->getMySqlBinding());
@@ -512,13 +521,14 @@ public:
     /// @tparam StatementIndex Type of the statement index enum.
     ///
     /// @param index Index of the query to be executed.
-    /// @param in_bindings Input bindings holding values to substitue placeholders
+    /// @param in_bindings Input bindings holding values to substitute placeholders
     /// in the query.
     ///
     /// @return Number of affected rows.
     template<typename StatementIndex>
     uint64_t updateDeleteQuery(const StatementIndex& index,
                                const MySqlBindingCollection& in_bindings) {
+        checkUnusable();
         std::vector<MYSQL_BIND> in_bind_vec;
         for (MySqlBindingPtr in_binding : in_bindings) {
             in_bind_vec.push_back(in_binding->getMySqlBinding());
@@ -554,7 +564,6 @@ public:
         return (static_cast<uint64_t>(mysql_stmt_affected_rows(statements_[index])));
     }
 
-
     /// @brief Commit Transactions
     ///
     /// Commits all pending database operations. On databases that don't
@@ -583,10 +592,8 @@ public:
     ///
     /// If the error is recoverable, the function will throw a DbOperationError.
     /// If the error is deemed unrecoverable, such as a loss of connectivity
-    /// with the server, the function will call invokeDbLostCallback(). If the
-    /// invocation returns false then either there is no callback registered
-    /// or the callback has elected not to attempt to reconnect, and a
-    /// DbUnrecoverableError is thrown.
+    /// with the server, the function will call startRecoverDbConnection() which
+    /// will start the connection recovery.
     ///
     /// If the invocation returns true, this indicates the calling layer will
     /// attempt recovery, and the function throws a DbOperationError to allow
@@ -603,7 +610,7 @@ public:
     ///        failed.
     template<typename StatementIndex>
     void checkError(const int status, const StatementIndex& index,
-                    const char* what) const {
+                    const char* what) {
         if (status != 0) {
             switch(mysql_errno(mysql_)) {
                 // These are the ones we consider fatal. Remember this method is
@@ -615,24 +622,24 @@ public:
             case CR_SERVER_GONE_ERROR:
             case CR_SERVER_LOST:
             case CR_OUT_OF_MEMORY:
-            case CR_CONNECTION_ERROR:
+            case CR_CONNECTION_ERROR: {
                 DB_LOG_ERROR(db::MYSQL_FATAL_ERROR)
                     .arg(what)
                     .arg(text_statements_[static_cast<int>(index)])
                     .arg(mysql_error(mysql_))
                     .arg(mysql_errno(mysql_));
 
-                // If there's no lost db callback or it returns false,
-                // then we're not attempting to recover so we're done.
-                if (!invokeDbLostCallback()) {
-                    isc_throw(db::DbUnrecoverableError,
-                              "database connectivity cannot be recovered");
-                }
+                // Mark this connection as no longer usable.
+                markUnusable();
+
+                // Start the connection recovery.
+                startRecoverDbConnection();
 
                 // We still need to throw so caller can error out of the current
                 // processing.
-                isc_throw(db::DbOperationError,
-                          "fatal database errror or connectivity lost");
+                isc_throw(db::DbConnectionUnusable,
+                          "fatal database error or connectivity lost");
+            }
             default:
                 // Connection is ok, so it must be an SQL error
                 isc_throw(db::DbOperationError, what << " for <"
@@ -644,6 +651,17 @@ public:
         }
     }
 
+    /// @brief The recover connection
+    ///
+    /// This function starts the recover process of the connection.
+    ///
+    /// @note The recover function must be run on the IO Service thread.
+    void startRecoverDbConnection() {
+        if (callback_ && io_service_) {
+            io_service_->post(std::bind(callback_, reconnectCtl()));
+        }
+    }
+
     /// @brief Prepared statements
     ///
     /// This field is public, because it is used heavily from MySqlConnection
@@ -661,9 +679,15 @@ public:
     /// This field is public, because it is used heavily from MySqlConnection
     /// and will be from MySqlHostDataSource.
     MySqlHolder mysql_;
+
+    /// @brief IOService object, used for all ASIO operations.
+    isc::asiolink::IOServicePtr io_service_;
+
+    /// @brief The callback used to recover the connection.
+    DbCallback callback_;
 };
 
-}; // end of isc::db namespace
-}; // end of isc namespace
+} // end of isc::db namespace
+} // end of isc namespace
 
 #endif // MYSQL_CONNECTION_H
